@@ -470,6 +470,17 @@ Arnolfini.IEFixNthChild = function () {
 	$(".threecol div.tileItem:nth-child(3n+2)").addClass("threecolNthChild");
 }
 
+Arnolfini.hideShareCounters = function ()
+{
+	$('.addthis_counter').each(function ()
+				{
+					if ($(this).text() == '0')
+					{
+						$(this).hide();
+					}
+				});
+}
+
 $(document).ready(function() {
 	Arnolfini.events();
 	Arnolfini.archiveShowButtons();
@@ -495,5 +506,7 @@ $(document).ready(function() {
 	{
 		Arnolfini.IEFixNthChild();
 	}
+	
+	setTimeout(Arnolfini.hideShareCounters, 3000);
 });
 
